/*	Hardware definitions for graphic LCD displays
	
		PA.0-7	I/O	LCD D0-7
	
		PE.0	Out	LCD E
		PE.4	Out	LCD RS
		PE.3	Out	LCD R/W_

		PE.1	Out	LCD CS
*/

/* LCD control signals */
#define	LCD_CS	1
#define	LCD_E		0
#define	LCD_RS	4
#define	LCD_RW	3


void MsDelay ( int iDelay )
{
	unsigned long ul0;
	ul0 = MS_TIMER;		// get current timer value
	while ( MS_TIMER < ul0 + (unsigned long) iDelay );
}

void UsDelay ( int iDelay )
{
	int i;
	iDelay /= 11;		// this is experimental, for a RCM2100
	for ( i=0; i<iDelay; i++ );
}


/* Low level functions */

#asm
;function requires two parameters:
;@sp+2= cmd to write
;@sp+4= data/parameter to write
;
LCD_WriteCmd::
	ld a,0x80				; PA0-7 = Inputs, read data from bus
	ioi ld (SPCR),a		; write it (no shadow, no one else uses port A)
	ld hl,PEDRShadow		; point to control port (shadow)
	ld de,PEDR				; point to control port
	set LCD_RW,(HL)		; Rise RW
	set LCD_RS,(HL)		; Rise RS
	ioi ldd					; do it
l1:
	ld hl,PEDRShadow		; point to control port (shadow)
	ld de,PEDR				; point to control port
	set LCD_E,(HL)			; Rise E
	ioi ldd					; do it
	ioi ld a,(PADR)		; Read status
	ld hl,PEDRShadow		; point to control port (shadow)
	ld de,PEDR				; point to control port
	res LCD_E,(HL)			; Lower E
	ioi ldd					; do it
	rla						; Check busy
	jr c,l1					; loop while busy

	ld a,0x84				; PA0-7 = Outputs, put data in bus
	ioi ld (SPCR),a		; write it (no shadow, no one else uses port A)
	ld hl,PEDRShadow		; point to control port (shadow)
	ld de,PEDR				; point to control port
	res LCD_RW,(HL)		; Lower RW
	ioi ldd					; do it
	ld hl,(sp+2)			; get cmd value (LSB)
	call LCD_Write			; write it
	ld hl,PEDRShadow		; point to control port (shadow)
	ld de,PEDR				; point to control port
	res LCD_RS,(HL)		; Lower RS
	ioi ldd					; do it
	ld hl,(sp+4)			; get data value (LSB)
LCD_Write:
	ld a,l
	ioi ld (PADR),a		; and write it (no shadow, no one else uses port A)
	ld hl,PEDRShadow		; point to control port (shadow)
	ld de,PEDR				; point to control port
	set LCD_E,(HL)			; Rise E
	ioi ldd					; do it
	ld hl,PEDRShadow		; point to control port (shadow)
	ld de,PEDR				; point to control port
	res LCD_E,(HL)			; Lower E
	ioi ldd					; do it
	ret

#endasm




void LCD_init ()
{
	WrPortI ( PEDR,&PEDRShadow,0x00 );		// Make sure Outputs are Low
	WrPortI ( PEDDR,&PEDDRShadow,'\B10011011' );	// PE0,1,3,4,7 = output
	WrPortI ( PEFR, &PEFRShadow, 0 );		// PE: no I/O strobe
	MsDelay ( 1000 );				// wait for LCD to reset itself

	BitWrPortI ( PEDR, &PEDRShadow, 0,LCD_CS );	// Lower CS

}


/* High level functions */

void LCD_set5x7()
{
	LCD_WriteCmd ( 1,'\B01110101' );					// 5x7 chars (6x8 frame)
	LCD_WriteCmd ( 2,39 );								// 40 chars (240/6)
	LCD_WriteCmd ( 3,63);								// 1/64 duty cycle (consult display datasheet)
	LCD_WriteCmd ( 4,7);									// Line at which to show cursor (8)
	LCD_WriteCmd ( 0,'\B00110000' );					// Display on, master, text, no cursor
}

void LCD_setgfx()
{
	LCD_WriteCmd ( 1,'\B01110111' );					// 7x7 chars (8x8 frame)
	LCD_WriteCmd ( 2,29 );								// 30 strips (bytes) (240/8)
	LCD_WriteCmd ( 3,63);								// 1/64 duty cycle (consult display datasheet)
	LCD_WriteCmd ( 0,'\B00110010' );					// Display on, master, graphics
}

void LCD_address ( int address )
{
	LCD_WriteCmd(10,address&0xFF);						// LO byte
	LCD_WriteCmd(11,(address>>8)&0xFF);					// HI byte
}

void LCD_home ( void )
{
	LCD_WriteCmd (8,0);						// display starts at address 0
	LCD_WriteCmd (9,0);
	LCD_address (0);							// address 0
}

void LCD_fill(int count,unsigned char pattern)
{
int i;
	LCD_home();										// address 0
	for(i=0;i<count;i++)
		LCD_WriteCmd(0x0C,pattern);			// fill with pattern
}


void LCD_printat (unsigned int cpl,unsigned int row, unsigned int col, char *ptr)
{
	LCD_address (cpl*row+col);					// set cursor address
 	while (*ptr)
		LCD_WriteCmd (0x0C,*ptr++);
}


/* Plot image data, 8 pixels per byte, MSB right */

void LCD_plot (int x, int y)
{
int strip,bit;
	strip=x>>3;											// strip = x/8
	bit=x&'\B0111';									// bit = remainder
	y=strip+30*y;
	LCD_address(y);									// address strip in gfx screen
	LCD_WriteCmd(0x0F,bit);							// set requested bit (great!)
}

/*
Image data for a 240x64 display can be easily extracted from XBM format (C string), 
if your display is of the STN- type, like in this example (many Cika 240x64's are STN-),
you'll have to color invert the picture.
Take a desired image, resize to 240x64, color reduce to 2 colors, [invert colors].
*/

void LCD_dump(unsigned char *imgdata)
{
int x;
		LCD_home();
		for(x=0;x<1920;x++)
			LCD_WriteCmd(0x0C,imgdata[x]);					// send data to display
}



/* MAIN PROGRAM */

main()
{
int i;

const static unsigned char rabbit[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0x07, 0x00, 0xfe, 0xff,
   0x00, 0xfc, 0x03, 0x00, 0x7f, 0x00, 0xe0, 0x0f, 0x20, 0x00, 0x00, 0xfc,
   0x3f, 0x3f, 0xfe, 0xff, 0xff, 0x7f, 0x00, 0xfc, 0xff, 0xff, 0xff, 0xff,
   0xfc, 0xff, 0xf3, 0x3f, 0xf8, 0x7f, 0xfe, 0xfd, 0xf9, 0x3f, 0x3c, 0xff,
   0x87, 0xcf, 0x87, 0xff, 0xff, 0xfc, 0x3f, 0x9f, 0xf9, 0xff, 0xff, 0xbf,
   0xff, 0xe3, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xf1, 0xff, 0xe3, 0x3f,
   0xff, 0xfd, 0xf8, 0xff, 0x19, 0xff, 0x3f, 0xe2, 0x8f, 0xff, 0xff, 0xfc,
   0x3f, 0xdf, 0xe7, 0xff, 0xff, 0x3f, 0xff, 0x9f, 0xff, 0xff, 0xff, 0xff,
   0xfc, 0xff, 0xf8, 0xff, 0xe7, 0x1f, 0xff, 0x79, 0xfc, 0xff, 0x83, 0xff,
   0x7f, 0xe2, 0xc7, 0xff, 0xff, 0xfe, 0x3f, 0xef, 0xcf, 0xff, 0xff, 0x1f,
   0xf0, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xf8, 0xff, 0xcf, 0x9f,
   0xff, 0x79, 0xfc, 0xff, 0x87, 0xff, 0xff, 0xe0, 0xc7, 0xff, 0xff, 0xfe,
   0x3f, 0xef, 0xbf, 0xff, 0xff, 0xef, 0xff, 0x7f, 0xfe, 0xff, 0xff, 0xff,
   0xfc, 0xff, 0xf8, 0xff, 0xdf, 0x8f, 0xff, 0x79, 0xfc, 0xff, 0x87, 0xff,
   0xff, 0xe0, 0xc7, 0xff, 0x7f, 0xfe, 0x3f, 0xdf, 0x7f, 0xfc, 0xff, 0xf7,
   0xff, 0xff, 0xf9, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xf8, 0xc1, 0xdf, 0xcf,
   0xff, 0x7b, 0xfc, 0xe0, 0x87, 0x1f, 0xfc, 0xf0, 0x07, 0xf8, 0x03, 0x86,
   0x3f, 0xdf, 0xff, 0xe3, 0xff, 0x0f, 0xf0, 0xff, 0xc7, 0xff, 0xff, 0xff,
   0xfc, 0xff, 0xf8, 0xc1, 0xdf, 0xe7, 0xf7, 0x7b, 0xfc, 0xe0, 0x87, 0x1f,
   0xfc, 0xf0, 0x03, 0xf8, 0x81, 0x03, 0x38, 0xc3, 0xff, 0x1f, 0xff, 0xff,
   0x0f, 0xf8, 0x3f, 0xfe, 0xff, 0xff, 0xfc, 0x7f, 0xfc, 0xc1, 0xdf, 0xe3,
   0xf7, 0x3b, 0xfe, 0xe0, 0xc7, 0x1f, 0xfc, 0xf0, 0x03, 0xf8, 0x81, 0xf9,
   0x03, 0x9c, 0xff, 0xff, 0xc0, 0xff, 0x01, 0xfe, 0xff, 0xf9, 0xff, 0xff,
   0xfc, 0x7f, 0xfc, 0xc0, 0xcf, 0xf3, 0xf3, 0x33, 0x7e, 0xf0, 0xc7, 0x0f,
   0xfe, 0xf0, 0x03, 0xf8, 0xc1, 0xf9, 0xff, 0x9f, 0xff, 0xff, 0x7f, 0x00,
   0xff, 0xff, 0xff, 0xf3, 0xff, 0xff, 0xfc, 0x7f, 0xfc, 0xf1, 0xef, 0xf1,
   0xe3, 0x33, 0xfe, 0xff, 0xc3, 0xff, 0x7f, 0xf0, 0x7b, 0xf8, 0xfd, 0xf8,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xe7, 0xff, 0xff,
   0xfc, 0x7f, 0xfc, 0xff, 0xe7, 0xf9, 0xe1, 0x33, 0xfe, 0xff, 0xc0, 0xff,
   0x1f, 0xf8, 0x7b, 0xfc, 0x7d, 0xe6, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xfc, 0x3f, 0xfc, 0xff, 0xf1, 0xfc,
   0xe1, 0x17, 0xfe, 0x7f, 0xc4, 0xff, 0x8f, 0xf8, 0x79, 0xfc, 0x3c, 0x7f,
   0x80, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xdf, 0xff, 0xff,
   0xfc, 0x3f, 0xfe, 0x7f, 0x78, 0xfc, 0xe0, 0x17, 0xff, 0xff, 0xe0, 0xff,
   0xbf, 0xf8, 0x79, 0xfc, 0xbc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xef, 0xff, 0xff, 0xfc, 0x3f, 0xfe, 0xff, 0x7c, 0xfe,
   0xe0, 0x17, 0xff, 0xff, 0xe1, 0xff, 0x3f, 0xf8, 0x79, 0xfc, 0xbe, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0xff,
   0xfc, 0x3f, 0x7e, 0xfc, 0x3c, 0xfe, 0xff, 0x07, 0x3f, 0xf0, 0xe3, 0x07,
   0x7e, 0xf8, 0x3d, 0xfe, 0xbe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xe7, 0xff, 0xff, 0xfc, 0x3f, 0x7e, 0xf8, 0x3d, 0xff,
   0xff, 0x07, 0x3f, 0xf0, 0xe3, 0x07, 0x7e, 0xfc, 0x3d, 0xfe, 0x3e, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xff, 0xff,
   0xfc, 0x1f, 0x7f, 0xf8, 0x9d, 0xff, 0xff, 0x07, 0x3f, 0xf0, 0xe3, 0x07,
   0x7e, 0xfc, 0x3c, 0x7e, 0x7e, 0xfc, 0x0f, 0xfc, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xf9, 0xff, 0xff, 0xfc, 0x1f, 0x7f, 0xf8, 0x89, 0xff,
   0xff, 0x8f, 0x3f, 0xf8, 0xf3, 0x07, 0x7f, 0xfc, 0x3c, 0x7e, 0xfe, 0x01,
   0x00, 0xfb, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3f, 0x00, 0xfe, 0xff, 0xff,
   0xfc, 0x1f, 0x3f, 0xf8, 0xc9, 0x1f, 0xe0, 0x8f, 0x3f, 0xff, 0xf1, 0xe7,
   0x3f, 0xfc, 0x3e, 0x7e, 0xff, 0xff, 0x3f, 0xe7, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xbf, 0xff, 0xff, 0xff, 0xff, 0xfc, 0x1f, 0x3f, 0xf0, 0xc3, 0x0f,
   0xc0, 0x8f, 0xff, 0xff, 0xf1, 0xff, 0x3f, 0xfc, 0x1e, 0x7f, 0xff, 0xff,
   0x3f, 0x9f, 0xff, 0xe1, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0xff,
   0xfc, 0x1f, 0xbf, 0xf0, 0xe3, 0x0f, 0xc0, 0x8f, 0xff, 0xff, 0xf0, 0xff,
   0x1f, 0xfe, 0x1e, 0x7f, 0xff, 0xff, 0x3f, 0x7f, 0xfe, 0x1e, 0xff, 0xff,
   0xff, 0xbf, 0x0f, 0xfc, 0xff, 0xff, 0xfc, 0x8f, 0xbf, 0xf0, 0xf3, 0x07,
   0xc0, 0xcf, 0xff, 0x3f, 0xf8, 0xff, 0x07, 0x7e, 0x1e, 0x3f, 0xc0, 0xff,
   0x3f, 0xff, 0x31, 0xff, 0xf8, 0xff, 0xff, 0x1f, 0xf0, 0xf3, 0xff, 0xff,
   0xfc, 0x8f, 0x9f, 0xf0, 0xf3, 0xf7, 0xc3, 0xcf, 0xff, 0x0f, 0xf8, 0xff,
   0x21, 0x7e, 0x1e, 0x3f, 0xc5, 0xff, 0x3f, 0xff, 0xdf, 0xff, 0xc7, 0xff,
   0xff, 0x9f, 0xff, 0xe7, 0xff, 0xff, 0xfc, 0x0f, 0x80, 0x00, 0x00, 0xf0,
   0x07, 0x00, 0x00, 0x80, 0x00, 0x00, 0x30, 0x00, 0x0f, 0x80, 0xc5, 0xff,
   0x3f, 0xff, 0xff, 0xff, 0x3f, 0xfe, 0xf1, 0xff, 0xff, 0xef, 0xff, 0xff,
   0xfc, 0x0f, 0xe0, 0x01, 0x00, 0xfc, 0x07, 0x00, 0x00, 0xc0, 0x00, 0x00,
   0x18, 0x80, 0x0f, 0xc0, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0x01,
   0xe6, 0xff, 0xff, 0xef, 0xff, 0xff, 0xfc, 0x0f, 0xe0, 0x01, 0x00, 0xfc,
   0x07, 0x00, 0x00, 0xf0, 0x00, 0x00, 0x1e, 0xc0, 0x0f, 0xe0, 0xff, 0xff,
   0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xef, 0xff, 0x01, 0xee, 0xff, 0xff,
   0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xdf, 0xdf, 0x07, 0xf0, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xe7, 0xff, 0xfe, 0xff, 0xff,
   0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff,
   0x7f, 0xc4, 0xff, 0xfe, 0xff, 0xff, 0xfc, 0xff, 0xfc, 0xff, 0xff, 0xcf,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3f, 0xf8, 0xfe, 0xff, 0xff,
   0xfc, 0x7f, 0xf8, 0xff, 0xff, 0xcf, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0x07, 0xff, 0xff, 0xff, 0xfc, 0x7f, 0xfc, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xfd, 0xff, 0xff, 0xff, 0xff,
   0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xfc, 0x7f, 0xfe, 0xfd, 0xd1, 0xcf, 0xcf, 0xcf, 0x0f, 0x7f, 0x7c, 0xf9,
   0xf1, 0xf9, 0xf9, 0xf1, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0x7f, 0xfc, 0xf8, 0x80, 0xcf,
   0x87, 0x87, 0x0f, 0x3e, 0x7c, 0xf8, 0xf0, 0xf0, 0xf0, 0xe1, 0xff, 0xff,
   0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xfc, 0xff, 0x7c, 0xf0, 0x80, 0xcf, 0xe7, 0x87, 0x0f, 0x1e, 0x7c, 0xf8,
   0xfc, 0xf9, 0xf0, 0xf1, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0x78, 0xf0, 0x84, 0xcf,
   0xe7, 0x07, 0x4f, 0x9e, 0x7c, 0xf8, 0xfc, 0xf9, 0xf0, 0xf9, 0xff, 0xff,
   0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xfc, 0xff, 0x79, 0xf8, 0x84, 0xcf, 0xe7, 0x07, 0x4f, 0x9e, 0x7c, 0xf8,
   0xfc, 0xf9, 0xf0, 0xf9, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0x7f, 0xf8, 0xf8, 0x84, 0xcf,
   0x87, 0x87, 0x4f, 0x1e, 0x7c, 0xf8, 0xf0, 0xf9, 0xf0, 0xf9, 0xff, 0xff,
   0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xfc, 0x7f, 0xf8, 0xf8, 0x84, 0xcf, 0x87, 0x87, 0x4f, 0x3e, 0x7c, 0xf8,
   0xf1, 0xf1, 0xf0, 0xf9, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xfd, 0xff, 0xff,
   0xdf, 0xdf, 0xff, 0xff, 0xff, 0xff, 0xfb, 0xfb, 0xf9, 0xff, 0xff, 0xff,
   0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xfc, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0x3f, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
 };


	LCD_init();
	while(1){

		LCD_setgfx();
		LCD_fill(30*64,0);					// clear (fill with 0's) (black)
		MsDelay ( 3000 );						// wait 3 secs
		LCD_fill(30*64,0xFF);				// 'white' fill
		MsDelay ( 3000 );						// wait 3 secs

		LCD_set5x7();
		LCD_fill(40*8,' ');					// clear (fill with spaces)
		LCD_printat(40,4,8,"Cika Electronica S.R.L.");
		MsDelay ( 3000 );						// wait 3 secs		

		LCD_setgfx();
		LCD_fill(30*64,0);					// clear (fill with 0's)
		for(i=0;i<240;i++)
			LCD_plot(i,32); 					// x axis
		for(i=0;i<64;i++)
			LCD_plot(120,i); 					// y axis
		for(i=-120;i<120;i++)
			LCD_plot(120+i,32-(int)(32*(sin(i*3.14159/120)))); // plot sin(x); 0,0 is at top left
		MsDelay ( 3000 );						// wait 3 secs

		LCD_dump(rabbit);
		MsDelay ( 6000 );						// wait 6 secs
	}
}
